# Text Highlighter

A Streamlit component for annotating text using text highlighting. Useful for NLP tasks.

## Installation

You can install the Text Highlighter package using the following command:

```bash
pip install text_highlighter
```

## Usage

In `example.py` you can find an example of how to use this repository. You can run the example by running the following command:

```bash
streamlit run example.py
```

The output will look like this:

![Example](img/example.png)

## Contribute

Feel free to add a pull request or open an issue if you have any questions or suggestions.
